# ISS Libs
![Release](https://img.shields.io/github/v/release/postersom/libs)
![Download](https://img.shields.io/github/downloads/postersom/libs/total)


☤ Quick Start
---------------

To install iss_libs, simply run the following at your prompt:

```bash
  # from pypi
  pip3 install iss-libs
  
  # from source
  pip3 install git+https://github.com/postersom/iss_libs.git

```
☤ Contributions
---------------
- Somsak Binyaranee (@postersom) - Tests / CI / Uploads to Pypi

☤ License
---------------
 
ISS Libs is released under the **MIT** license. Please see the
[LICENSE](https://github.com/postersom/libs/blob/master/LICENSE>)
file for more details.